IconifyAWSIconsIconSetD class
Class to access the icon data for AWS Icons. All icons are stored as static const strings. This class contains the icons that start with "D".
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- database → const String
-
- databaseMigrationService → const String
-
- databaseMigrationServiceDatabaseMigrationWorkflowJob → const String
-
- dataExchange → const String
-
- dataExchangeForApis → const String
-
- dataFirehose → const String
-
- dataPipeline → const String
-
- dataStream → const String
-
- dataStreamDark → const String
-
- datasync → const String
-
- datasyncAgent → const String
-
- datasyncDiscovery → const String
-
- dataTable → const String
-
- dataTableDark → const String
-
- datazone → const String
-
- datazoneBusinessDataCatalog → const String
-
- datazoneDataPortal → const String
-
- datazoneDataProjects → const String
-
- deadlineCloud → const String
-
- deepcomposer → const String
-
- deepLearningAmis → const String
-
- deepLearningContainers → const String
-
- deeplens → const String
-
- deepracer → const String
-
- detective → const String
-
- developerTools → const String
-
- deviceFarm → const String
-
- devopsGuru → const String
-
- devopsGuruInsights → const String
-
- directConnect → const String
-
- directConnectGateway → const String
-
- directoryService → const String
-
- directoryServiceAdConnector → const String
-
- directoryServiceAwsManagedMicrosoftAd → const String
-
- directoryServiceSimpleAd → const String
-
- disk → const String
-
- diskDark → const String
-
- distroForOpentelemetry → const String
-
- document → const String
-
- documentDark → const String
-
- documentdb → const String
-
- documentdbElasticClusters → const String
-
- documents → const String
-
- documentsDark → const String
-
- dynamodb → const String
-
- dynamodbAmazonDynamodbAccelerator → const String
-
- dynamodbAttribute → const String
-
- dynamodbAttributes → const String
-
- dynamodbGlobalSecondaryIndex → const String
-
- dynamodbItem → const String
-
- dynamodbItems → const String
-
- dynamodbStandardAccessTableClass → const String
-
- dynamodbStandardInfrequentAccessTableClass → const String
-
- dynamodbStream → const String
-
- dynamodbTable → const String
-