IconifyAWSIconsIconSetF class
Class to access the icon data for AWS Icons. All icons are stored as static const strings. This class contains the icons that start with "F".
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fargate → const String
-
- faultInjectionService → const String
-
- fileCache → const String
-
- fileCacheHybridNfsLinkedDatasets → const String
-
- fileCacheOnPremisesNfsLinkedDatasets → const String
-
- fileCacheS3LinkedDatasets → const String
-
- finspace → const String
-
- firewall → const String
-
- firewallDark → const String
-
- firewallManager → const String
-
- folder → const String
-
- folderDark → const String
-
- folders → const String
-
- foldersDark → const String
-
- forecast → const String
-
- forums → const String
-
- forumsDark → const String
-
- fraudDetector → const String
-
- freertos → const String
-
- frontEndWebMobile → const String
-
- fsx → const String
-
- fsxForLustre → const String
-
- fsxForNetappOntap → const String
-
- fsxForOpenzfs → const String
-
- fsxForWfs → const String
-